summaryrefslogtreecommitdiff
path: root/apps/openmw/mwmechanics/spellabsorption.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'apps/openmw/mwmechanics/spellabsorption.hpp')
-rw-r--r--apps/openmw/mwmechanics/spellabsorption.hpp5
1 files changed, 3 insertions, 2 deletions
diff --git a/apps/openmw/mwmechanics/spellabsorption.hpp b/apps/openmw/mwmechanics/spellabsorption.hpp
index 0fe501df91..5537483a48 100644
--- a/apps/openmw/mwmechanics/spellabsorption.hpp
+++ b/apps/openmw/mwmechanics/spellabsorption.hpp
@@ -10,8 +10,9 @@ namespace MWWorld
namespace MWMechanics
{
- // Try to absorb a spell based on the magnitude of every Spell Absorption effect source on the target.
- bool absorbSpell(const std::string& spellId, const MWWorld::Ptr& caster, const MWWorld::Ptr& target);
+ void absorbSpell(const std::string& spellId, const MWWorld::Ptr& caster, const MWWorld::Ptr& target);
+ // Calculate the chance to absorb a spell based on the magnitude of every Spell Absorption effect source on the target.
+ int getAbsorbChance(const MWWorld::Ptr& caster, const MWWorld::Ptr& target);
}
#endif